/**
 * 
 */
package com.sample.workitem;

import java.lang.reflect.Array;
import java.net.HttpURLConnection;
import java.net.URL;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.nio.file.StandardCopyOption;

import org.kie.api.runtime.process.WorkItem;
import org.kie.internal.executor.api.Command;
import org.kie.internal.executor.api.CommandContext;
import org.kie.internal.executor.api.ExecutionResults;

/**
 * Test command. Download file from url and save in temporary directory
 * 
 * @author tgratkowski
 *
 */
public class FileCommand implements Command {

	protected ExecutionResults executionResults;

	public ExecutionResults execute(CommandContext commandContext) {

		System.out.println("Command executed on executor with data " + commandContext.getData());
		WorkItem workItem = (WorkItem) commandContext.getData("workItem");

		// Do the heavy lifting here ...
		Object[] parameters = getParameters(workItem);
		String fileToDownload = (String) workItem.getParameter("fileToDownload");

		System.out.println(">>>>>>>>>>>>>>>>>> fileToDownload: " + fileToDownload);
		for (Object object : parameters) {
			System.out.println(">>>>>>>>>>>>>>>>>> parameters: " + object);
		}

		executionResults = new ExecutionResults();

		try {
			if (fileToDownload != null && !fileToDownload.isEmpty()) {
				URL website = new URL(fileToDownload);
				HttpURLConnection httpcon = (HttpURLConnection) website.openConnection();
				httpcon.addRequestProperty("User-Agent", "Mozilla/4.76");
				System.out.println(">>>>>>>>>>>>>>>>>> Save '" + website.getFile() + "' file to : " + System.getProperty("java.io.tmpdir"));
				Path destination = Paths.get(System.getProperty("java.io.tmpdir") + website.getFile());
				Files.copy(httpcon.getInputStream(), destination, StandardCopyOption.REPLACE_EXISTING);

			}
		} catch (Exception ex) {
			ex.printStackTrace();
		}

		return executionResults;
	}

	/**
	 * Return table of parameter
	 * 
	 * @param workItem
	 * @return
	 */
	public Object[] getParameters(WorkItem workItem) {
		Object[] parameters = null;

		if (workItem.getParameter("Parameter") instanceof Object[]) {
			parameters = (Object[]) workItem.getParameter("Parameter");
		} else if (workItem.getParameter("Parameter") != null && workItem.getParameter("Parameter").getClass().isArray()) {
			int length = Array.getLength(workItem.getParameter("Parameter"));
			parameters = new Object[length];
			for (int i = 0; i < length; i++) {
				parameters[i] = Array.get(workItem.getParameter("Parameter"), i);
			}
		} else {
			parameters = new Object[] { workItem.getParameter("Parameter") };
		}

		return parameters;
	}
}
